@@ -8,8 +8,8 @@
 
 from .base import TrainingCallback, PredictionCallback, CallbackException
 from .early_stopping import EarlyStopping
-from .logging import EpochProgressLogger, BatchProgressLogger, \
-    PredictionProgressLogger
+from .logging import EpochProgressLogger, BatchProgressLogger, PredictionProgressLogger
 from .parallel import SynchronizationCallback, ModelSharingCallback
 from .saving import ModelSaverCallback
-from .schedule import ParameterScheduler
+from .schedule import LearningRateScheduler, ParameterScheduler
+from .tracking import NeptuneTracker
