@@ -4,7 +4,7 @@
 #
 #  Created by Oliver Borchert on May 20, 2019.
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
-#  
+#
 
 import torch
 import sklearn.metrics as metrics
@@ -16,8 +16,8 @@ def accuracy(y_pred, y_true):
     Parameters:
     -----------
     - y_pred: torch.LongTensor [N] or torch.FloatTensor [N, C]
-        The class predictions made by the model. Can be either specific classes
-        or predictions for each class.
+        The class predictions made by the model. Can be either specific classes or predictions for
+        each class.
     - y_true: torch.LongTensor [N]
         The actual classes.
 
@@ -37,13 +37,13 @@ def recall(y_pred, y_true, c=1):
     Parameters:
     -----------
     - y_pred: torch.LongTensor [N] or torch.FloatTensor [N, C]
-        The class predictions made by the model. Can be either specific classes
-        or predictions for each class.
+        The class predictions made by the model. Can be either specific classes or predictions for
+        each class.
     - y_true: torch.LongTensor [N]
         The actual classes.
     - c: int, default: 1
-        The class to calculate the recall score for. Default assumes a binary
-        classification setting.
+        The class to calculate the recall score for. Default assumes a binary classification
+        setting.
 
     Returns:
     --------
@@ -57,7 +57,7 @@ def recall(y_pred, y_true, c=1):
 
     correct = (y_pred[y_true == y_pred]).sum()
     true_correct = y_true.sum()
-    
+
     return correct.float() / true_correct.float()
 
 
@@ -68,13 +68,13 @@ def precision(y_pred, y_true, c=1):
     Parameters:
     -----------
     - y_pred: torch.LongTensor [N] or torch.FloatTensor [N, C]
-        The class predictions made by the model. Can be either specific classes
-        or predictions for each class.
+        The class predictions made by the model. Can be either specific classes or predictions for
+        each class.
     - y_true: torch.LongTensor [N]
         The actual classes.
     - c: int, default: 1
-        The class to calculate the recall score for. Default assumes a binary
-        classification setting.
+        The class to calculate the recall score for. Default assumes a binary classification
+        setting.
 
     Returns:
     --------
@@ -88,7 +88,7 @@ def precision(y_pred, y_true, c=1):
 
     correct = (y_pred[y_true == y_pred]).sum()
     true_correct = y_pred.sum()
-    
+
     return correct.float() / true_correct.float()
 
 
@@ -99,13 +99,13 @@ def f1_score(y_pred, y_true, c=1):
     Parameters:
     -----------
     - y_pred: torch.LongTensor [N] or torch.FloatTensor [N, C]
-        The class predictions made by the model. Can be either specific classes
-        or predictions for each class.
+        The class predictions made by the model. Can be either specific classes or predictions for
+        each class.
     - y_true: torch.LongTensor [N]
         The actual classes.
     - c: int, default: 1
-        The class to calculate the recall score for. Default assumes a binary
-        classification setting.
+        The class to calculate the recall score for. Default assumes a binary classification
+        setting.
 
     Returns:
     --------
@@ -138,7 +138,7 @@ def roc_auc_score(y_pred, y_true, c=1):
         "ROC-AUC score only works in the binary case."
 
     return torch.as_tensor(
-        metrics.roc_auc_score(y_true.numpy(), y_pred.numpy())
+        metrics.roc_auc_score(y_true.numpy() == c, y_pred.numpy() == c)
     )
 
 
@@ -162,7 +162,7 @@ def average_precision(y_pred, y_true, c=1):
         "Average precision only work in the binary case."
 
     return torch.as_tensor(
-        metrics.average_precision_score(y_true.numpy(), y_pred.numpy())
+        metrics.average_precision_score(y_true.numpy() == c, y_pred.numpy() == c)
     )
 
 
@@ -172,6 +172,6 @@ def _ensure_classes(y):
 
     if y.dim() == 2:
         return torch.argmax(y, dim=-1)
-    elif y.dtype == torch.float:
+    if y.dtype == torch.float:
         return torch.round(y)
     return y
