@@ -4,7 +4,7 @@
 #
 #  Created by Oliver Borchert on May 18, 2019.
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
-#  
+#
 
 import torch.distributions as dist
 
@@ -28,7 +28,7 @@ def generate_noise(shape, noise_type='normal'):
     """
     if noise_type == 'normal':
         return dist.Normal(0, 1).sample(shape)
-    elif noise_type == 'uniform':
+    if noise_type == 'uniform':
         return dist.Uniform(-1, 1).sample(shape)
     raise ValueError(f'Invalid noise type {noise_type}.')
     
\ No newline at end of file
