@@ -6,5 +6,5 @@
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
 #
 
-from .loss import BCELoss
+from .loss import WeightedBCELoss
 from .lstm import StackedLSTM, StackedLSTMCell
