@@ -4,7 +4,7 @@
 #
 #  Created by Oliver Borchert on May 11, 2019.
 #  Copyright (c) 2019 Oliver Borchert. All rights reserved.
-#  
+#
 
 import os
 import sys
@@ -16,13 +16,13 @@ _ERASE_LINE = '\x1b[2K'
 
 class ProgressBar:
     """
-    The progress bar can be used to print progress for a specific task where
-    N work items have to be processed. The progress bar also measures the
-    execution time and provides an estimated remaining time for the  operation.
+    The progress bar can be used to print progress for a specific task where N work items have to
+    be processed. The progress bar also measures the execution time and provides an estimated
+    remaining time for the  operation.
 
-    A common use case for the progress bar are for-loops where one work item is
-    completed per iteration. The progress bar is intended to be used either 
-    from within a with statement or a for-loop.
+    A common use case for the progress bar are for-loops where one work item is completed per
+    iteration. The progress bar is intended to be used either from within a with statement or a
+    for-loop.
     """
 
     # MARK: Static Methods
@@ -55,13 +55,11 @@ class ProgressBar:
         - total: int
             The number of work items to be processed.
         - file: str, default: None
-            If given, defines the file where the progress bar should write to
-            instead of the command line. Intermediate directories are created
-            automatically.
+            If given, defines the file where the progress bar should write to instead of the
+            command line. Intermediate directories are created automatically.
         - verbose: bool, default: True
-            Whether to actually log anything. This is useful in cases where
-            logging should be turned of dynamically without introducing
-            additional control flow.
+            Whether to actually log anything. This is useful in cases where logging should be
+            turned of dynamically without introducing additional control flow.
         """
         self.verbose = verbose
         self.current = 0
@@ -77,47 +75,46 @@ class ProgressBar:
     # MARK: Instance Methods
     def start(self):
         """
-        Starts to record the progress of the operation. Time measuring is
-        initiated and the beginning of the operation is indicated on the
-        command line.
+        Starts to record the progress of the operation. Time measuring is initiated and the
+        beginning of the operation is indicated on the command line.
 
-        This method should never be called explicitly. It is implicitly called
-        at the beginning of a with statement.
+        This method should never be called explicitly. It is implicitly called at the beginning of
+        a with statement.
         """
         self.tic = time.time()
         self._print_progress(compute_eta=False)
 
     def step(self):
         """
-        Tells the progress bar that one work item has been processed. The 
-        command line output is updated as well as the estimated finishing time
-        of the operation.
+        Tells the progress bar that one work item has been processed. The command line output is
+        updated as well as the estimated finishing time of the operation.
 
-        If used from within a with statement, this method must be called
-        explicitly, otherwise, it should not be called.
+        If used from within a with statement, this method must be called explicitly, otherwise, it
+        should not be called.
         """
         self.current += 1
         self._print_progress()
 
-    def finish(self, metrics={}):
+    def finish(self, metrics=None):
         """
-        Stops the progress bar and prints the total duration of the operation.
-        If metrics are given, these will be printed along with the duration.
+        Stops the progress bar and prints the total duration of the operation. If metrics are given,
+        these will be printed along with the duration.
+
+        If metrics are given, this method must be called explicitly, otherwise, it is implicitly
+        called at the end of a with statement or for loop.
 
-        If metrics are given, this method must be called explicitly, otherwise,
-        it is implicitly called at the end of a with statement or for loop.
-        
         Note:
         -----
         Do not call this method multiple times.
 
         Parameters:
         -----------
-        - metrics: dict, default: {}
-            The metrics to print as key-value pairs. Usually, they provide more
-            information about the operation whose progress has been tracked.
+        - metrics: dict, default: None
+            The metrics to print as key-value pairs. Usually, they provide more information about
+            the operation whose progress has been tracked.
         """
-        toc = time.time()
+        if metrics is None:
+            metrics = {}
         self._print_done(metrics)
         self.tic = None
 
@@ -139,13 +136,14 @@ class ProgressBar:
             self.start()
             self._counter = 0
             return self._counter
-        elif self._counter < self.total - 1:
+
+        if self._counter < self.total - 1:
             self.step()
             self._counter += 1
             return self._counter
-        else:
-            self.finish()
-            raise StopIteration
+
+        self.finish()
+        raise StopIteration
 
     # MARK: Private Methods
     def _print_progress(self, compute_eta=True):
@@ -174,10 +172,10 @@ class ProgressBar:
     def _print_done(self, metrics):
         if not self.verbose:
             return
-            
+
         elapsed = datetime.timedelta(0, int(time.time() - self.tic))
         m_strings = []
-        for k, v in sorted(metrics.items(), key=lambda k:k[0]):
+        for k, v in sorted(metrics.items(), key=lambda k: k[0]):
             split = k.split('__')
             if len(split) > 1:
                 f = split[1]
@@ -197,13 +195,12 @@ class ProgressBar:
 
 def ensure_valid_directories(file):
     """
-    Creates intermediate directories to ensure that files can be saved to their
-    specified directory.
+    Creates intermediate directories to ensure that files can be saved to their specified directory.
 
     Parameters:
     -----------
     - file: str
         The absolute path to the file whose directory structure to ensure.
     """
-    dir = "/".join(file.split('/')[:-1])
-    os.makedirs(dir, exist_ok=True)
+    directory = "/".join(file.split('/')[:-1])
+    os.makedirs(directory, exist_ok=True)
